summaryrefslogtreecommitdiffstats
path: root/juk/systemtray.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'juk/systemtray.cpp')
-rw-r--r--juk/systemtray.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/juk/systemtray.cpp b/juk/systemtray.cpp
index e71fc37d..48e6ba5f 100644
--- a/juk/systemtray.cpp
+++ b/juk/systemtray.cpp
@@ -432,7 +432,7 @@ TQPixmap SystemTray::createPixmap(const TQString &pixName)
TQImage bgImage = bgPix.convertToImage(); // Probably 22x22
TQImage fgImage = fgPix.convertToImage(); // Should be 16x16
- KIconEffect::semiTransparent(bgImage);
+ TDEIconEffect::semiTransparent(bgImage);
copyImage(bgImage, fgImage, (bgImage.width() - fgImage.width()) / 2,
(bgImage.height() - fgImage.height()) / 2);
@@ -602,7 +602,7 @@ static bool copyImage(TQImage &dest, TQImage &src, int x, int y)
if((y + src.height()) >= dest.height())
return false;
// We want to use KIconEffect::overlay to do this, since it handles
// alpha, but the images need to be the same size. We can handle that.
TQImage large_src(dest);
@@ -628,7 +628,7 @@ static bool copyImage(TQImage &dest, TQImage &src, int x, int y)
// Apply effect to image
- KIconEffect::overlay(dest, large_src);
+ TDEIconEffect::overlay(dest, large_src);
return true;
}
@@ -602,7 +602,7 @@ static bool copyImage(TQImage &dest, TQImage &src, int x, int y)
if((y + src.height()) >= dest.height())
return false;
- // We want to use KIconEffect::overlay to do this, since it handles
+ // We want to use TDEIconEffect::overlay to do this, since it handles
// alpha, but the images need to be the same size. We can handle that.
TQImage large_src(dest);